@@ -11,7 +11,7 @@ use Hash::Merge 'merge';
 use Moo;
 use App::Sqitch::Types qw(Sqitch Target);
 
-our $VERSION = '0.9996';
+our $VERSION = '0.9997';
 
 use constant ENGINES => qw(
     pg
@@ -20,6 +20,7 @@ use constant ENGINES => qw(
     oracle
     firebird
     vertica
+    exasol
 );
 
 has sqitch => (
@@ -326,6 +327,8 @@ Returns the list of supported engines, currently:
 
 =item * C<vertica>
 
+=item * C<exasol>
+
 =back
 
 =head2 Class Methods
@@ -700,7 +703,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2015 iovation Inc.
+Copyright (c) 2012-2018 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -721,4 +724,3 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 
 =cut
-
