@@ -1,7 +1,7 @@
 BEGIN;
 
 SET client_min_messages = warning;
-CREATE SCHEMA :"registry";
+CREATE SCHEMA IF NOT EXISTS :"registry";
 
 COMMENT ON SCHEMA :"registry" IS 'Sqitch database deployment metadata v1.0.';
 
